function R=rk4s3(f,g,s,a,b,x0,y0,z0,h)
%----------------------------------------------
% Runge-Kutta Method of Order 4.
% Approximation of the solution of the IVP for the system of three ODE 
% x'(t)=f(t,x(t),y(t),z(t)), y'(t)=g(t,x(t),y(t),z(t)), z'(t)=s(t,x(t),y(t),z(t)) 
% with x(a)=x0, y(a)=y0 and z(a)=z0 over [a,b] by using the formula
% x(n+1)=x(n)+h*(k1+2k2+2k3+k4)/6;
% y(n+1)=y(n)+h*(c1+2c2+2c3+c4)/6;
% z(n+1)=z(n)+h*(d1+2d2+2d3+d4)/6;
%----------------------------------------------
% Input- f, g and s are the functions entered as strings 'f', 'g' and 's';
%          -a and b are the left and right end points;
%          - x0, y0 and z0 are initial conditions;
%          - M is the number of steps;
% Output-R=[T', X', Y', Z'], where T is the time vector, whereas X,Y,Z are the position vectors.
%----------------------------------------------
M=(b-a)/h;
T=zeros(1,M+1);
X=zeros(1,M+1);
Y=zeros(1,M+1);
Z=zeros(1,M+1);
T=a:h:b;
X(1)=x0;
Y(1)=y0;
Z(1)=z0;
tt=5; % time interval to display pictures
for j=1:M
    k1=feval(f,T(j),X(j),Y(j),Z(j));
    c1=feval(g,T(j),X(j),Y(j),Z(j));
    d1=feval(s,T(j),X(j),Y(j),Z(j));
    %-------
    k2=feval(f,T(j)+h/2,X(j)+h*k1/2,Y(j)+h*c1/2,Z(j)+h*d1/2);
    c2=feval(g,T(j)+h/2,X(j)+h*k1/2,Y(j)+h*c1/2,Z(j)+h*d1/2);
    d2=feval(s,T(j)+h/2,X(j)+h*k1/2,Y(j)+h*c1/2,Z(j)+h*d1/2);
    %-------
    k3=feval(f,T(j)+h/2,X(j)+h*k2/2,Y(j)+h*c2/2,Z(j)+h*d2/2);
    c3=feval(g,T(j)+h/2,X(j)+h*k2/2,Y(j)+h*c2/2,Z(j)+h*d2/2);
    d3=feval(s,T(j)+h/2,X(j)+h*k2/2,Y(j)+h*c2/2,Z(j)+h*d2/2);
    %-------
    k4=feval(f,T(j)+h,X(j)+h*k3,Y(j)+h*c3,Z(j)+h*d3);
    c4=feval(g,T(j)+h,X(j)+h*k3,Y(j)+h*c3,Z(j)+h*d3);
    d4=feval(s,T(j)+h,X(j)+h*k3,Y(j)+h*c3,Z(j)+h*d3);
    %-------
    X(j+1)=X(j)+h*(k1+2*k2+2*k3+k4)/6;
    Y(j+1)=Y(j)+h*(c1+2*c2+2*c3+c4)/6;
    Z(j+1)=Z(j)+h*(d1+2*d2+2*d3+d4)/6;
    %-------
%    if mod(j,tt)==0
%     figure(6) %plot in real time
%     plot3(X(j+1),Y(j+1),Z(j+1),'r','MarkerSize',8)
%     grid on 
%     view([6.0 14.0])
%     axis([-20 20 -50 50 0 45])
%     xlabel('x','FontName','Times New Roman','FontSize',16)
%     ylabel('y','FontName','Times New Roman','FontSize',16)
%     zlabel('z','FontName','Times New Roman','FontSize',16)
%     hold on
%     end;
end;
R=[T',X',Y',Z'];